gensprep.o gensprep.d : ../../../icu/source/tools/gensprep/gensprep.c \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/tools/gensprep/../toolutil/toolutil.h \
 ../../../icu/source/tools/gensprep/../toolutil/unewdata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/tools/gensprep/../toolutil/uoptions.h \
 ../../../icu/source/tools/gensprep/../toolutil/uparse.h \
 ../../../icu/source/common/sprpimpl.h \
 ../../../icu/source/common/unicode/ustring.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/uiter.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/common/unicode/usprep.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/utrie.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/ubidi_props.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/uset_imp.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/tools/gensprep/gensprep.h
