datamap.o datamap.d : ../../../icu/source/tools/ctestfw/datamap.cpp \
 ../../../icu/source/tools/ctestfw/unicode/datamap.h \
 ../../../icu/source/common/unicode/resbund.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/uloc.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/common/unicode/locid.h \
 ../../../icu/source/common/unicode/strenum.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/tools/ctestfw/unicode/testtype.h \
 ../../../icu/source/common/hash.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h ../../../icu/source/common/uhash.h \
 ../../../icu/source/common/uelement.h
