pkgitems.o pkgitems.d : ../../../icu/source/tools/toolutil/pkgitems.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/uloc.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/uinvchar.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/ucmndata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/umapfile.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/tools/toolutil/swapimpl.h \
 ../../../icu/source/tools/toolutil/toolutil.h \
 ../../../icu/source/common/unicode/errorcode.h \
 ../../../icu/source/tools/toolutil/package.h \
 ../../../icu/source/tools/toolutil/pkg_imp.h \
 ../../../icu/source/common/uresdata.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/resource.h \
 ../../../icu/source/common/restrace.h \
 ../../../icu/source/common/ucnv_bld.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/ucnv_cnv.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/uset_imp.h \
 ../../../icu/source/common/ucnvmbcs.h \
 ../../../icu/source/common/ucnv_ext.h \
 ../../../icu/source/common/ucnv_io.h
