pkg_genc.o pkg_genc.d : ../../../icu/source/tools/toolutil/pkg_genc.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/tools/toolutil/filestrm.h \
 ../../../icu/source/tools/toolutil/toolutil.h \
 ../../../icu/source/common/unicode/errorcode.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/tools/toolutil/uoptions.h \
 ../../../icu/source/tools/toolutil/pkg_genc.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/tools/toolutil/filetools.h \
 ../../../icu/source/common/charstr.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h
