uparse.o uparse.d : ../../../icu/source/tools/toolutil/uparse.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/unicode/ustring.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/uiter.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/tools/toolutil/filestrm.h \
 ../../../icu/source/tools/toolutil/uparse.h \
 ../../../icu/source/common/ustr_imp.h \
 ../../../icu/source/common/unicode/utf8.h
