xmlparser.o xmlparser.d : ../../../icu/source/tools/toolutil/xmlparser.cpp \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/i18n/unicode/regex.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/common/unicode/utext.h \
 ../../../icu/source/common/unicode/chariter.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/i18n/unicode/uregex.h \
 ../../../icu/source/tools/toolutil/filestrm.h \
 ../../../icu/source/tools/toolutil/xmlparser.h \
 ../../../icu/source/common/uvector.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/uarrsort.h \
 ../../../icu/source/common/uelement.h ../../../icu/source/common/hash.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/uhash.h
