ctest.o ctest.d : ../../../icu/source/tools/ctestfw/ctest.c \
 ../../../icu/source/common/unicode/utrace.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/tools/ctestfw/../toolutil/udbgutil.h \
 ../../../icu/source/tools/ctestfw/unicode/ctest.h \
 ../../../icu/source/tools/ctestfw/unicode/testtype.h
